==> haskell-fourmolu-0.10.0.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.10.0.0
visibility:           public
id:                   fourmolu-0.10.0.0-FsMsdH7lThjBm2LvROEALZ
key:                  fourmolu-0.10.0.0-FsMsdH7lThjBm2LvROEALZ
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  560b310f4c9e10fea2273fc7cc09d1f4
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       Ormolu.Config.TH Ormolu.Config.Types GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.10.0.0-FsMsdH7lThjBm2LvROEALZ
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    MemoTrie-0.6.11-683GLED39WN6p5yoyZxvVY
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O mtl-2.2.2
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-45VGakeqcUODctOJKhXaAz
    yaml-0.11.11.2-JT20IpT71d6A5uGNbiwjEW

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fourmolu-0.10.0.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.10.0.0
visibility:           public
id:                   fourmolu-0.10.0.0-5wgTVPolyV91IwT0evhG2K
key:                  fourmolu-0.10.0.0-5wgTVPolyV91IwT0evhG2K
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  75bfe4893f369142a70974fa3b033eee
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       Ormolu.Config.TH Ormolu.Config.Types GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.10.0.0-5wgTVPolyV91IwT0evhG2K
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    MemoTrie-0.6.11-683GLED39WN6p5yoyZxvVY
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O mtl-2.2.2
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-45VGakeqcUODctOJKhXaAz
    yaml-0.11.11.2-8e5unmrXdnl2ZPxT6bSVG7

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
